@@ -8,6 +8,7 @@ from rest_framework.response import Response
 from .aggregates import CountIf
 from .aggregates import Percentile
 from .utils import Aggregator
+from .enums import Aggregation
 
 
 class AggregationMixin:
@@ -25,7 +26,7 @@ class AggregationMixin:
         group_by = self._get_group_by(request=request)
 
         limit = self._get_limit(request=request)
-        limit_field = self._get_limit_by_field(request=request)
+        limit_field = self._get_limit_by(request=request)
         if limit and not limit_field and len(group_by) > 0:
             limit_field = group_by[0]
 
@@ -42,26 +43,26 @@ class AggregationMixin:
         return Response(result)
 
     def _get_annotation(self, aggregation: str, request) -> dict:
-        if aggregation == 'count':
+        if aggregation == Aggregation.COUNT:
             return {"value": models.Count('id')}
 
-        if aggregation == 'sum':
+        if aggregation == Aggregation.SUM:
             aggregation_field = self._get_aggregation_field(request=request)
             return {"value": models.Sum(aggregation_field)}
 
-        if aggregation == 'average':
+        if aggregation == Aggregation.AVERAGE:
             aggregation_field = self._get_aggregation_field(request=request)
             return {"value": models.Avg(aggregation_field)}
 
-        if aggregation == 'minimum':
+        if aggregation == Aggregation.MIN:
             aggregation_field = self._get_aggregation_field(request=request)
             return {"value": models.Min(aggregation_field)}
 
-        if aggregation == 'maximum':
+        if aggregation == Aggregation.MAX:
             aggregation_field = self._get_aggregation_field(request=request)
             return {"value": models.Max(aggregation_field)}
 
-        if aggregation == 'percentile':
+        if aggregation == Aggregation.PERCENTILE:
             aggregation_field = self._get_aggregation_field(request=request)
             percentile = self._get_percentile(request)
             output_type = self._get_output_type(request=request)
@@ -70,7 +71,7 @@ class AggregationMixin:
                                             output_field=models.FloatField())}
             return {"value": Percentile(aggregation_field, percentile)}
 
-        if aggregation == "percent":
+        if aggregation == Aggregation.PERCENT:
             additional_query = self._get_additional_query(request=request)
             return {
                 "numerator": CountIf(additional_query),
@@ -92,7 +93,7 @@ class AggregationMixin:
 
     @staticmethod
     def _get_group_by(request) -> list:
-        group_by = request.query_params.get("groupByFields", None)
+        group_by = request.query_params.get("groupBy", None)
         group_by = group_by.split(",") if group_by else []
 
         return group_by
@@ -107,8 +108,8 @@ class AggregationMixin:
         return int(limit) if limit else None
 
     @staticmethod
-    def _get_limit_by_field(request) -> (str, None):
-        return request.query_params.get("limitByField", None)
+    def _get_limit_by(request) -> (str, None):
+        return request.query_params.get("limitBy", None)
 
     @staticmethod
     def _get_show_other(request) -> bool:
