@@ -19,22 +19,27 @@ class AggregationTests(APITestCase):
     def test_annotations(self, query, expected_response):
         response = self.client.get(self.URL, query, format="json")
         self.assertEqual(response.status_code, 200,
-                         msg=f"Failed on: {query}\n"
-                             f"Response: {response.data}")
+                         msg=f"Failed on: {query}"
+                             f"\nResponse: {response.data}"
+                             f"\nExpected: {expected_response}")
         self.assertEqual(response.data, expected_response,
-                         msg=f"Failed on: {query}\n"
-                             f"Response: {response.data}\n"
-                             f"Expected: {expected_response}")
+                         msg=f"Failed on: {query}"
+                             f"\nResponse: {response.data}"
+                             f"\nExpected: {expected_response}")
 
     @parameterized.expand(GROUP_TESTING)
     def test_group_by_fields(self, query, expected_response):
         response = self.client.get(self.URL, query, format="json")
         self.assertEqual(response.status_code, 200,
-                         msg=f"Failed on: {query}\n"
-                             f"Response: {response.data}")
+                         msg=f"Failed on: {query}"
+                             f"\nResponse: {response.data}"
+                             f"\nExpected: {expected_response}")
         self.assertEqual(len(response.data), len(expected_response),
-                         msg=f"Failed on: {query}\n"
-                             f"Response: {response.data}")
+                         msg=f"Failed on: {query}"
+                             f"\nResponse: {response.data}"
+                             f"\nExpected: {expected_response}")
         for result in response.data:
             self.assertIn(result, expected_response,
-                          msg=f"Failed on: {query}\n")
+                          msg=f"Failed on: {query}"
+                              f"\nResponse: {response.data}"
+                              f"\nExpected: {expected_response}")
