@@ -74,12 +74,12 @@ ANNOTATIONS_TESTING = [
 ]
 
 GROUP_TESTING = [
-    ({"aggregation": "count", "groupByFields": "group1"},
+    ({"aggregation": "count", "groupBy": "group1"},
      [{"group1": "1", "value": 2},
       {"group1": "2", "value": 1},
       {"group1": "3", "value": 3}]),
 
-    ({"aggregation": "count", "groupByFields": "group1,group2"},
+    ({"aggregation": "count", "groupBy": "group1,group2"},
      [{"group1": "1", "group2": "1", "value": 1},
       {"group1": "1", "group2": "2", "value": 1},
       {"group1": "2", "group2": "1", "value": 1},
@@ -92,38 +92,38 @@ GROUP_TESTING = [
                                       "data": {"attribute": "group2",
                                                "operator": "=",
                                                "value": "2"}}),
-      "groupByFields": "group1"},
+      "groupBy": "group1"},
      [{"group1": "1", "numerator": 1, "denominator": 2, "value": 0.5},
       {"group1": "2", "numerator": 0, "denominator": 1, "value": 0},
       {"group1": "3", "numerator": 1, "denominator": 3, "value": 1 / 3}]),
 
-    ({"aggregation": "count", "groupByFields": "group1",
+    ({"aggregation": "count", "groupBy": "group1",
       "limit": 1, "order": "desc"},
      [{"group1": "3", "value": 3}]),
 
-    ({"aggregation": "count", "groupByFields": "group1",
-      "limit": 1, "limitByField": "group1", "order": "asc"},
+    ({"aggregation": "count", "groupBy": "group1",
+      "limit": 1, "limitBy": "group1", "order": "asc"},
      [{"group1": "2", "value": 1}]),
 
-    ({"aggregation": "count", "groupByFields": "group1",
+    ({"aggregation": "count", "groupBy": "group1",
       "limit": 1, "order": "desc", "showOther": 1},
      [{"group1": "3", "value": 3},
       {"group1": "Other", "value": 3}]),
 
-    ({"aggregation": "count", "groupByFields": "group1",
+    ({"aggregation": "count", "groupBy": "group1",
       "limit": 3, "order": "desc", "showOther": 1},
      [{"group1": "3", "value": 3},
       {"group1": "1", "value": 2},
       {"group1": "2", "value": 1}]),
 
-    ({"aggregation": "count", "groupByFields": "group1,group2",
+    ({"aggregation": "count", "groupBy": "group1,group2",
       "limit": 1, "order": "desc"},
      [{"group1": "3", "group2": "1", "value": 1},
       {"group1": "3", "group2": "2", "value": 1},
       {"group1": "3", "group2": "3", "value": 1}]),
 
-    ({"aggregation": "count", "groupByFields": "group2,group1",
-      "limit": 1, "limitByField": "group1", "order": "desc"},
+    ({"aggregation": "count", "groupBy": "group2,group1",
+      "limit": 1, "limitBy": "group1", "order": "desc"},
      [{"group1": "3", "group2": "1", "value": 1},
       {"group1": "3", "group2": "2", "value": 1},
       {"group1": "3", "group2": "3", "value": 1}]),
@@ -133,7 +133,7 @@ GROUP_TESTING = [
                                       "data": {"attribute": "group2",
                                                "operator": "=",
                                                "value": "2"}}),
-      "groupByFields": "group1",
+      "groupBy": "group1",
       "limit": 1, "order": "desc"},
      [{"group1": "1", "numerator": 1, "denominator": 2, "value": 0.5}]),
 
@@ -142,7 +142,7 @@ GROUP_TESTING = [
                                       "data": {"attribute": "group2",
                                                "operator": "=",
                                                "value": "2"}}),
-      "groupByFields": "group1",
+      "groupBy": "group1",
       "limit": 1, "order": "desc", "showOther": 1},
      [{"group1": "1", "numerator": 1, "denominator": 2, "value": 0.5},
       {"group1": "Other", "numerator": 1, "denominator": 4,
@@ -151,7 +151,7 @@ GROUP_TESTING = [
     ({"aggregation": "count",
       "annotations": json.dumps({"date_day": {"field": "date",
                                               "kind": "day"}}),
-      "groupByFields": "date_day"},
+      "groupBy": "date_day"},
      [{"date_day": date(2020, 10, 1), "value": 2},
       {"date_day": date(2020, 10, 31), "value": 1},
       {"date_day": date(2020, 11, 1), "value": 2},
@@ -160,7 +160,7 @@ GROUP_TESTING = [
     ({"aggregation": "count",
       "annotations": json.dumps({"datetime_day": {"field": "datetime",
                                                   "kind": "day"}}),
-      "groupByFields": "datetime_day",
+      "groupBy": "datetime_day",
       "orderBy": "datetime_day"},
      [{"datetime_day": datetime(2020, 10, 1), "value": 2},
       {"datetime_day": datetime(2020, 10, 31), "value": 1},
@@ -171,7 +171,7 @@ GROUP_TESTING = [
       "annotations": json.dumps({"date_day": {"field": "date", "kind": "day"},
                                  "datetime_day": {"field": "datetime",
                                                   "kind": "day"}}),
-      "groupByFields": "date_day,datetime_day",
+      "groupBy": "date_day,datetime_day",
       "orderBy": "datetime_day"},
      [{"date_day": date(2020, 10, 1),
        "datetime_day": datetime(2020, 11, 2), "value": 1},
@@ -189,7 +189,7 @@ GROUP_TESTING = [
     ({"aggregation": "average", "aggregationField": "float",
       "annotations": json.dumps({"date_day": {"field": "date",
                                               "kind": "day"}}),
-      "groupByFields": "date_day"},
+      "groupBy": "date_day"},
      [{"date_day": date(2020, 10, 1), "value": 3},
       {"date_day": date(2020, 10, 31), "value": 3},
       {"date_day": date(2020, 11, 1), "value": 3},
@@ -198,7 +198,7 @@ GROUP_TESTING = [
     ({"aggregation": "count",
       "annotations": json.dumps({"date_day": {"field": "date",
                                               "kind": "day"}}),
-      "groupByFields": "group1,date_day",
+      "groupBy": "group1,date_day",
       "limit": 1, "order": "desc",
       "showOther": 1},
      [{"group1": "3", "date_day": date(2020, 10, 1), "value": 1},
@@ -211,8 +211,8 @@ GROUP_TESTING = [
     ({"aggregation": "count",
       "annotations": json.dumps({"date_day": {"field": "date",
                                               "kind": "day"}}),
-      "groupByFields": "date_day,group1",
-      "limit": 1, "limitByField": "group1", "order": "desc",
+      "groupBy": "date_day,group1",
+      "limit": 1, "limitBy": "group1", "order": "desc",
       "showOther": 1},
      [{"group1": "3", "date_day": date(2020, 10, 1), "value": 1},
       {"group1": "3", "date_day": date(2020, 10, 31), "value": 1},
